`crypyto`_
==========

crypyto [*kri*-**pahy**-*toh*] is a Python package that provides simple
usage of cryptography tools and ciphers on your programs.

Check the `complete docs`_!

Getting Started
---------------

These instructions will get you a copy of the project up and running on
your local machine for development and testing purposes.

Dependencies
~~~~~~~~~~~~

-  Python >= 3.5
-  Python packages (no need to worry if you use pip to install crypyto):

   -  `unidecode`_ to normalize strings
   -  `Pillow`_ to handle images

Installing
~~~~~~~~~~

The easiest way to install crypyto is by using pip:

::

   pip install crypyto

You can also clone this repository using git

::

   git clone https://github.com/yanorestes/crypyto.git

Usage
-----

Ciphers crypyto supports:

-  `Polybius Square`_
-  `Atbash`_
-  `Caesar Cipher`_
-  `ROT13`_
-  `Affine Cipher`_
-  `Rail Fence Cipher`_

TODO Ciphers:

-  KEYWORD
-  BEAUFORT
-  PORTA
-  VIGENERE
-  GRONSFELD
-  AUTOKEY
-  BACON
-  CHAOCIPHER
-  ADFGVX
-  PLAYFAIR
-  FOUR-SQUARE
-  ONE-TIME PAD
-  BIFID
-  HILL CIPHER
-  ENIGMA

Substitution Alphabets crypyto supports:

-  `Morse Code`_ 
-  `Templar Cipher`_

TODO Substitution Alphabets:

-  Pigpen
-  ASL
-  BSL
-  Maze
-  Flag semaphore
-  Binary
-  Hexadecimal
-  Octal
-  L33TSP34K
-  T9
-  Base64
-  Braille

TODO Features:

-  Cipher identifier
-  Auto decoder

Authors
-------

-  **Yan Orestes** - *Initial work* - `yanorestes`_

License
-------

This project is licensed under the MIT License - see the `LICENSE`_ file
for details

.. _crypyto: https://crypyto.readthedocs.io/en/latest/
.. _complete docs: https://crypyto.readthedocs.io/en/latest/
.. _unidecode: https://pypi.org/project/Unidecode/
.. _Pillow: https://pypi.org/project/Pillow/
.. _Polybius Square: https://en.wikipedia.org/wiki/Polybius_square
.. _Atbash: https://en.wikipedia.org/wiki/Atbash
.. _Caesar Cipher: https://en.wikipedia.org/wiki/Caesar_cipher
.. _ROT13: https://en.wikipedia.org/wiki/ROT13
.. _Affine Cipher: https://en.wikipedia.org/wiki/Affine_cipher
.. _Rail Fence Cipher: https://en.wikipedia.org/wiki/Rail_fence_cipher
.. _Morse Code: https://en.wikipedia.org/wiki/Morse_code
.. _Templar Cipher: https://en.wikipedia.org/wiki/Pigpen_cipher#Variants
.. _yanorestes: https://github.com/yanorestes
.. _LICENSE: https://github.com/yanorestes/crypyto/blob/master/LICENSE.txt